TransactionValidator

Struct TransactionValidator 

pub struct TransactionValidator { /* private fields */ }

Implementations

Source

impl TransactionValidator

Source

impl TransactionValidator

pub fn new( database: &impl SubstateDatabase, network_definition: &NetworkDefinition, ) -> Self

This is the best constructor to use, as it reads the configuration dynamically Note that the validator needs recreating every time a protocol update runs, as the config can get updated then.

pub fn new_for_latest_simulator() -> Self

pub fn new_with_latest_config(network_definition: &NetworkDefinition) -> Self

pub fn new_with_static_config( config: TransactionValidationConfig, network_id: u8, ) -> Self

pub fn new_with_latest_config_network_agnostic() -> Self

pub fn new_with_static_config_network_agnostic( config: TransactionValidationConfig, ) -> Self

pub fn network_id(&self) -> Option<u8>

Will typically be Some, but None if the validator is network-independent.

pub fn config(&self) -> &TransactionValidationConfig

pub fn preparation_settings(&self) -> &PreparationSettings

Source

impl TransactionValidator

Source

impl TransactionValidator

pub fn validate_notarized_v2( &self, prepared: PreparedNotarizedTransactionV2, ) -> Result<ValidatedNotarizedTransactionV2, TransactionValidationError>

pub fn validate_preview_transaction_v2( &self, prepared: PreparedPreviewTransactionV2, ) -> Result<ValidatedPreviewTransactionV2, TransactionValidationError>

pub fn validate_transaction_header_v2( &self, header: &TransactionHeaderV2, ) -> Result<(), HeaderValidationError>

pub fn validate_signed_partial_transaction_v2( &self, prepared: PreparedSignedPartialTransactionV2, ) -> Result<ValidatedSignedPartialTransactionV2, TransactionValidationError>

pub fn validate_transaction_tree_v2( &self, signed_intent_tree: &impl SignedIntentTreeStructure, root_intent_core: &PreparedIntentCoreV2, non_root_subintents: &PreparedNonRootSubintentsV2, ) -> Result<ValidatedTransactionTreeV2, TransactionValidationError>

pub fn validate_v2_intent_core( &self, intent_core: &PreparedIntentCoreV2, aggregation: &mut AcrossIntentAggregation, is_subintent: bool, ) -> Result<ManifestYieldSummary, IntentValidationError>

pub fn validate_intent_header_v2( &self, header: &IntentHeaderV2, aggregation: &mut AcrossIntentAggregation, ) -> Result<(), HeaderValidationError>

pub fn validate_message_v2( &self, message: &MessageV2, ) -> Result<(), InvalidMessageError>

pub fn validate_manifest_v2( &self, instructions: &[InstructionV2], blobs: &IndexMap<Hash, Vec<u8>>, children: &IndexSet<ChildSubintentSpecifier>, is_subintent: bool, ) -> Result<ManifestYieldSummary, ManifestValidationError>

The is_subintent property indicates whether it should be treated as a subintent. A subintent is able to YIELD_TO_PARENT and is required to end with a YIELD_TO_PARENT.